# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.01) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory
#
# Generated from Nauru.
#
# Do not edit this file directly.
#
package DateTime::TimeZone::Pacific::Nauru;

use strict;

use Class::Singleton;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::Pacific::Nauru::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
  {
    'short_name' => 'LMT',
    'utc_end' => '60590551940',
    'utc_start' => $DateTime::TimeZone::NEG_INFINITY,
    'local_end' => '60590592000',
    'offset' => 40060,
    'local_start' => '-inf'
  },
  {
    'short_name' => 'NRT',
    'utc_end' => '61258336200',
    'utc_start' => '60590551940',
    'local_end' => '61258377600',
    'offset' => 41400,
    'local_start' => '60590593340'
  },
  {
    'short_name' => 'JST',
    'utc_end' => '61334722800',
    'utc_start' => '61258336200',
    'local_end' => '61334755200',
    'offset' => 32400,
    'local_start' => '61258368600'
  },
  {
    'short_name' => 'NRT',
    'utc_end' => '62430006600',
    'utc_start' => '61334722800',
    'local_end' => '62430048000',
    'offset' => 41400,
    'local_start' => '61334764200'
  },
  {
    'short_name' => 'NRT',
    'utc_end' => $DateTime::TimeZone::INFINITY,
    'utc_start' => '62430006600',
    'offset' => 43200
  }
]
;

sub _new_instance
{
    return shift->_init( @_, spans => $spans );
}



1;

__END__

=head1 NAME

DateTime::TimeZone::Pacific::Nauru - Time zone data for Pacific/Nauru

=head1 SYNOPSIS

  my $timezone = DateTime::TimeZone->new( name => 'Pacific/Nauru' );

=head1 DESCRIPTION

This module is an internal timezone definition data file used by
DateTime::TimeZone.  You do not need to use this module directly.

=cut

