# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.01) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory
#
# Generated from St_Vincent.
#
# Do not edit this file directly.
#
package DateTime::TimeZone::America::St_Vincent;

use strict;

use Class::Singleton;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::America::St_Vincent::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
  {
    'short_name' => 'LMT',
    'utc_end' => '59611176296',
    'utc_start' => $DateTime::TimeZone::NEG_INFINITY,
    'local_end' => '59611161600',
    'offset' => -14696,
    'local_start' => '-inf'
  },
  {
    'short_name' => 'KMT',
    'utc_end' => '60305313896',
    'utc_start' => '59611176296',
    'local_end' => '60305299200',
    'offset' => -14696,
    'local_start' => '59611161600'
  },
  {
    'short_name' => 'AST',
    'utc_end' => $DateTime::TimeZone::INFINITY,
    'utc_start' => '60305313896',
    'offset' => -14400
  }
]
;

sub _new_instance
{
    return shift->_init( @_, spans => $spans );
}



1;

__END__

=head1 NAME

DateTime::TimeZone::America::St_Vincent - Time zone data for America/St_Vincent

=head1 SYNOPSIS

  my $timezone = DateTime::TimeZone->new( name => 'America/St_Vincent' );

=head1 DESCRIPTION

This module is an internal timezone definition data file used by
DateTime::TimeZone.  You do not need to use this module directly.

=cut

