# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.01) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory
#
# Generated from Kuala_Lumpur.
#
# Do not edit this file directly.
#
package DateTime::TimeZone::Asia::Kuala_Lumpur;

use strict;

use Class::Singleton;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::Asia::Kuala_Lumpur::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
  {
    'short_name' => 'LMT',
    'utc_end' => '59295517992',
    'utc_start' => $DateTime::TimeZone::NEG_INFINITY,
    'local_end' => '59295542400',
    'offset' => 24408,
    'local_start' => '-inf'
  },
  {
    'short_name' => 'SMT',
    'utc_end' => '60097482276',
    'utc_start' => '59295517992',
    'local_end' => '60097507200',
    'offset' => 24924,
    'local_start' => '59295542916'
  },
  {
    'short_name' => 'MALT',
    'utc_end' => '60968048400',
    'utc_start' => '60097482276',
    'local_end' => '60968073600',
    'offset' => 25200,
    'local_start' => '60097507476'
  },
  {
    'short_name' => 'MALT',
    'utc_end' => '61255932000',
    'utc_start' => '60968048400',
    'local_end' => '61255958400',
    'offset' => 26400,
    'local_start' => '60968074800'
  },
  {
    'short_name' => 'JST',
    'utc_end' => '61367814000',
    'utc_start' => '61255932000',
    'local_end' => '61367846400',
    'offset' => 32400,
    'local_start' => '61255964400'
  },
  {
    'short_name' => 'MALT',
    'utc_end' => '61504504800',
    'utc_start' => '61367814000',
    'local_end' => '61504531200',
    'offset' => 26400,
    'local_start' => '61367840400'
  },
  {
    'short_name' => 'MALT',
    'utc_end' => '62524715400',
    'utc_start' => '61504504800',
    'local_end' => '62524742400',
    'offset' => 27000,
    'local_start' => '61504531800'
  },
  {
    'short_name' => 'MYT',
    'utc_end' => $DateTime::TimeZone::INFINITY,
    'utc_start' => '62524715400',
    'offset' => 28800
  }
]
;

sub _new_instance
{
    return shift->_init( @_, spans => $spans );
}



1;

__END__

=head1 NAME

DateTime::TimeZone::Asia::Kuala_Lumpur - Time zone data for Asia/Kuala_Lumpur

=head1 SYNOPSIS

  my $timezone = DateTime::TimeZone->new( name => 'Asia/Kuala_Lumpur' );

=head1 DESCRIPTION

This module is an internal timezone definition data file used by
DateTime::TimeZone.  You do not need to use this module directly.

=cut

